Combines two distribution functions with given weights by `weights`
Arguments
- y.seq
sequence of possible y values
- ecdflist
list of ecdf objects (distribution functions) to combine
- weights
a vector of weights to put on each distribution function; if weights are not provided then equal weight is given to each distribution function
- ...
additional arguments that can be past to BMisc::make_dist