| get_Yibar | R Documentation |
A function to calculate the average outcome across all time periods separately for each unit in a panel data setting (this function can also be used to recover covariates, etc.).
get_Yibar(df, idname, yname)
df |
the data.frame used in the function |
idname |
name of column that holds the unit id |
yname |
name of column containing the outcome (or other variable) for which to calculate its outcome in the immediate pre-treatment period |
n <- 50
id <- rep(seq_len(n), each = 4)
t <- rep(1:4, n)
y <- rnorm(n * 4)
dta <- data.frame(id = id, t = t, y = y)
dta$Yibar <- get_Yibar(dta, idname = "id", yname = "y")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.