A function that calculates the first difference in a panel data
setting. If the data.frame that is passed in has nxT rows, the resulting
vector will also have nxT elements with one element for each unit set to be
NA.
Usage
get_first_difference(df, idname, yname, tname)
Arguments
df
the data.frame used in the function
idname
name of column that holds the unit id
yname
name of column containing the outcome (or other variable)
for which to calculate its outcome in the immediate pre-treatment period