id2rownum: Take particular id and convert to row number

View source: R/BMisc.R

id2rownumR Documentation

Take particular id and convert to row number

Description

id2rownum takes an id and converts it to the right row number in the dataset; ids should be unique in the dataset that is, don't pass the function panel data with multiple same ids

Usage

id2rownum(id, data, idname)

Arguments

id

a particular id

data

data frame

idname

unique id


BMisc documentation built on Aug. 22, 2026, 5:07 p.m.