invert_ecdf: Invert Ecdf

View source: R/BMisc.R

invert_ecdfR Documentation

Invert Ecdf

Description

take an ecdf object and invert it to get a step-quantile function

Usage

invert_ecdf(df)

Arguments

df

an ecdf object

Value

stepfun object that contains the quantiles of the df

Examples

y <- rnorm(100)
F <- ecdf(y)
Finv <- invert_ecdf(F)
Finv(0.5) ## approximate median


BMisc documentation built on Aug. 22, 2026, 5:07 p.m.