R/BMisc.R
lhs_vars.Rd
Take a formula and return a vector of the variables on the left hand side, it will return NULL for a one sided formula
lhs_vars(formula)
a formula
vector of variable names
ff <- yvar ~ x1 + x2 lhs_vars(ff) #> [1] "yvar"