orig2t_inner: orig2t_inner

View source: R/BMisc.R

orig2t_innerR Documentation

orig2t_inner

Description

A helper function to switch from original t values to "new" t values (which are just time periods going from 1 to total number of available periods).

Usage

orig2t_inner(orig, original_time.periods)

Arguments

orig

a single original time period to convert to new time period

original_time.periods

vector containing all original time periods.


BMisc documentation built on Aug. 22, 2026, 5:07 p.m.