powered by
compare_binary takes in a variable e.g. union and runs bivariate regression of x on treatment (for summary statistics)
compare_binary
compare_binary( x, on, dta, w = rep(1, nrow(dta)), report = c("diff", "levels", "both") )
matrix of results
variables to run regression on
binary variable
the data to use
weights
which type of report to make; diff is the difference between the two variables by group
dta <- data.frame(x = rnorm(100), treat = rep(c(0, 1), 50)) compare_binary("x", "treat", dta, report = "diff")
Run the code above in your browser using DataLab