A function to calculate the average outcome across all time
periods separately for each unit in a panel data setting (this function can also
be used to recover covariates, etc.).
Usage
get_Yibar(df, idname, yname)
Arguments
df
the data.frame used in the function
idname
name of column that holds the unit id
yname
name of column containing the outcome (or other variable)
for which to calculate its outcome in the immediate pre-treatment period