| invert_ecdf | R Documentation |
take an ecdf object and invert it to get a step-quantile function
invert_ecdf(df)
df |
an ecdf object |
stepfun object that contains the quantiles of the df
y <- rnorm(100)
F <- ecdf(y)
Finv <- invert_ecdf(F)
Finv(0.5) ## approximate median
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.