Learn R Programming

BMisc (version 1.4.9)

invert_ecdf: Invert Ecdf

Description

take an ecdf object and invert it to get a step-quantile function

Usage

invert_ecdf(df)

Value

stepfun object that contains the quantiles of the df

Arguments

df

an ecdf object

Examples

Run this code
y <- rnorm(100)
F <- ecdf(y)
Finv <- invert_ecdf(F)
Finv(0.5) ## approximate median

Run the code above in your browser using DataLab